==> svelte-components-0.0.3.tgz: package/rollup.config.js <==
import svelte from 'rollup-plugin-svelte';
import typescript from '@rollup/plugin-typescript';
import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import livereload from 'rollup-plugin-livereload';
import del from 'rollup-plugin-delete'
import { terser } from 'rollup-plugin-terser';
import css from 'rollup-plugin-css-only';
import pkg from './package.json';

const production = !process.env.ROLLUP_WATCH;

const name = pkg.name.replace(/^(@\S+\/)?(svelte-)?(\S+)/, '$3').replace(/^\w/, m => m.toUpperCase()).replace(/-\w/g, m => m[1].toUpperCase());

const LIB = pkg.library
const APP = pkg.application

const BUNDLE = pkg.bundle

const UMD = pkg.main
const CJS = pkg.node
const ESM = pkg.module
const IIFE = pkg.main.replace('.js','.min.js')

function serve() {
	let server;
	function toExit() { if (server) server.kill(0) }
	return {
		writeBundle() {
			if (server) return;
			server = require('child_process').spawn('yarn', ['run', 'start', '--', '--dev'], { stdio: ['ignore', 'inherit', 'inherit'], shell: true });
			process.on('SIGTERM', toExit);
			process.on('exit', toExit);
		}
	};
}

const plugins = [
	svelte({
		include: 'src/**/*.svelte',
		// enable run-time checks when not in production
		compilerOptions: { dev: !production },
		...require('./svelte.config')
	}),
	// we'll extract any component CSS out into a separate file - better for performance
	css({ output: 'bundle.css' }),
	// If you have external dependencies installed from npm, you'll most likely need these plugins.
	// In some cases you'll need additional configuration - consult the documentation for details:
	// https://github.com/rollup/plugins/tree/master/packages/commonjs
	resolve({ browser: true, dedupe: ['svelte'] }),
	commonjs(),
	typescript({ sourceMap: !production }),
	// In dev mode, call `yarn run start` once the bundle has been generated
	!production && serve(),
	// Watch the `demo` directory and refresh the browser on changes when not in production
	!production && livereload({ watch: 'demo' }),
	// If we're building for production (npm run build instead of npm run dev), minify
	production && terser()
]

const watch = { clearScreen: false }

export default [{
	input: APP,
	output: { file: BUNDLE, sourcemap: !production, format: 'umd', name },
	plugins: [
		del({ targets: 'demo/build/*' }),
		...plugins
	],
	watch: watch,
},{
	input: LIB,
	output: [
		{ file: UMD, sourcemap: !production, format: 'umd', name },
		{ file: CJS, sourcemap: !production, format: 'cjs', name },
		{ file: ESM, sourcemap: !production, format: 'es', name },
		{ file: IIFE, sourcemap: !production, format: 'iife', name }
	],
	plugins: [
		del({ targets: 'dist/*' }),
		...plugins
	]
}];

==> svelte-components-0.0.5.tgz: package/rollup.config.js <==
import svelte from 'rollup-plugin-svelte';
import typescript from '@rollup/plugin-typescript';
import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import livereload from 'rollup-plugin-livereload';
import del from 'rollup-plugin-delete'
import { terser } from 'rollup-plugin-terser';
import css from 'rollup-plugin-css-only';
import pkg from './package.json';

const production = !process.env.ROLLUP_WATCH;

const name = pkg.name.replace(/^(@\S+\/)?(svelte-)?(\S+)/, '$3').replace(/^\w/, m => m.toUpperCase()).replace(/-\w/g, m => m[1].toUpperCase());

const LIB = pkg.library
const UMD = pkg.main
const CJS = pkg.node
const ESM = pkg.module
const IIFE = pkg.main.replace('.js','.min.js')

function serve() {
	let server;
	function toExit() { if (server) server.kill(0) }
	return {
		writeBundle() {
			if (server) return;
			server = require('child_process').spawn('yarn', ['run', 'start', '--', '--dev'], { stdio: ['ignore', 'inherit', 'inherit'], shell: true });
			process.on('SIGTERM', toExit);
			process.on('exit', toExit);
		}
	};
}

const plugins = [
	svelte({
		include: 'src/**/*.svelte',
		// enable run-time checks when not in production
		compilerOptions: { dev: !production },
		...require('./svelte.config')
	}),
	// we'll extract any component CSS out into a separate file - better for performance
	css({ output: 'bundle.css' }),
	// If you have external dependencies installed from npm, you'll most likely need these plugins.
	// In some cases you'll need additional configuration - consult the documentation for details:
	// https://github.com/rollup/plugins/tree/master/packages/commonjs
	resolve({ browser: true, dedupe: ['svelte'] }),
	commonjs(),
	typescript({ sourceMap: !production }),
	// In dev mode, call `yarn run start` once the bundle has been generated
	!production && serve(),
	// Watch the `public` directory and refresh the browser on changes when not in production
	!production && livereload({ watch: 'public' }),
	// If we're building for production (npm run build instead of npm run dev), minify
	production && terser()
]

const watch = { clearScreen: false }

export default {
	input: LIB,
	output: [
		{ file: UMD, sourcemap: !production, format: 'umd', name },
		{ file: CJS, sourcemap: !production, format: 'cjs', name },
		{ file: ESM, sourcemap: !production, format: 'es', name },
		{ file: IIFE, sourcemap: !production, format: 'iife', name }
	],
	plugins: [
		del({ targets: 'dist/*' }),
		...plugins
	],
	watch: watch
};
